@@ -150,6 +150,10 @@ class IndentingGenerator(NamespacedGenerator):
     '''
     XML generator with pretty-printing.
     '''
+    def __init__(self, *args, **kwargs):
+        self._text_wrap = kwargs.pop('text_wrap', True)
+        super(IndentingGenerator, self).__init__(*args, **kwargs)
+
     def _fill(self, value, indent=None):
         if indent is None:
             indent = u'  ' * len(self.stack)
@@ -170,7 +174,7 @@ class IndentingGenerator(NamespacedGenerator):
     def element(self, name, attrs={}, namespaces={}, text=u''):
         indent = u'  ' * len(self.stack)
         self.file.write(u'\n%s' % indent)
-        if len(text) > 70:
+        if len(text) > 70 and self._text_wrap:
             fill = self._fill(text, indent + u'  ')
             text = u'%s\n%s' % (fill, indent)
         return super(IndentingGenerator, self).element(name, attrs, namespaces, text)
@@ -198,7 +202,7 @@ class Queue(object):
         return result
 
 
-def xml(file, root, attrs={}, namespaces={}, indent=False):
+def xml(file, root, attrs={}, namespaces={}, indent=False, text_wrap=True):
     '''
     Creates a streaming XML generator.
 
@@ -211,7 +215,7 @@ def xml(file, root, attrs={}, namespaces={}, indent=False):
     - indent: whether to pretty-print XML, True or False (default)
     '''
     if indent:
-        return IndentingGenerator(file, root, attrs, namespaces)
+        return IndentingGenerator(file, root, attrs, namespaces, text_wrap=text_wrap)
     elif namespaces:
         return NamespacedGenerator(file, root, attrs, namespaces)
     else:
